@@ -29,7 +29,7 @@ kstructure <- function(x) {
    dom <- as.set(unique(unlist(as.list(x))))
    x <- set_union(x, set(set(), dom))
    names(x) <- NULL
-   class(x) <- unique(c("kstructure", class(x)))
+   class(x) <- unique(c("kstructure", "kfamset", class(x)))
 
    ### return structure
    x
